# lbox-example

This is an example module which can be cloned and reused to develop modules under the `lbox` namespace.

## Module Status: Experimental

**TLDR: This module may be removed or altered at any given time and there is no offical support.**

Please see [here](https://docs.labelbox.com/docs/product-release-phases) for the formal definition of `Experimental`.